package explorer;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.io.File;
import java.text.DateFormat;
import java.text.DateFormatSymbols;
import java.util.Date;
import java.util.Hashtable;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeExpansionEvent;
import javax.swing.event.TreeExpansionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeNode;

public class ExplorerGUI extends JFrame {

    JTree explorerTree;
    JScrollPane scrollWindow;
    public ExplorerGUI() {

	setPreferredSize(new Dimension(500, 500));
	setVisible(true);
	setDefaultCloseOperation(EXIT_ON_CLOSE);
	setLayout(new BorderLayout());
	dodajKomponente();
	pack();
    }

    public void dodajKomponente() {
	
	FSTreeNode root = new FSTreeNode(new File("C:/"));
	//inicijalno ucitavamo samo prvi nivo fajl sistema,
	//a maxDubina nam je ogranicenje do kojeg inicijalno ucitavamo
	FSTreeModel model = new FSTreeModel(root,1);
	explorerTree = new JTree(model);
	//nakon toga cekamo akciju korisnika, i hvatamo momenat
	//kada se klikne na plusic za rasirenje drveta
	explorerTree.addTreeExpansionListener(new TreeExpansionListener(){
	   @Override
	    public void treeCollapsed(TreeExpansionEvent event) {
	        // TODO Auto-generated method stub
	        
	    }
	   @Override
	public void treeExpanded(TreeExpansionEvent event) {
	       
	       JTree drvo=(JTree)event.getSource();
	       //uzimamo mesto gde je kliknut + na drvetu
	       FSTreeNode kliknut=(FSTreeNode) event.getPath().getLastPathComponent();
	       //uzimamo model
	       FSTreeModel model=(FSTreeModel)drvo.getModel();
	       //sirimo samo taj deo drveta, konsultovanjem modela naravno
	       model.loadOne(kliknut);
	       
	}
	});
	scrollWindow=new JScrollPane();
	scrollWindow.setViewportView(explorerTree);
	getContentPane().add(scrollWindow, BorderLayout.CENTER);
    }

    /**
     * @param args
     */
    public static void main(String[] args) {
	// TODO Auto-generated method stub
	ExplorerGUI of = new ExplorerGUI();

    }

}

class FSTreeModel extends DefaultTreeModel {
    FSTreeNode root;
    int maxDepth;

    public FSTreeModel(TreeNode root) {
	super(root);
    }

    public FSTreeModel(FSTreeNode root, int maxDepth) {
	super(root);
	this.root = root;
	this.maxDepth=maxDepth;
	//ucitavamo samo jedan nulti nivo
	load(root,0);
    }

    private void load(FSTreeNode node, int depth) {

	if(depth==maxDepth)
	    return;
	File f = new File(node.path);
	File[] fajlovi = f.listFiles();
	if (fajlovi != null) {
	    for (int i = 0; i < fajlovi.length; i++) {
		FSTreeNode fsnode = new FSTreeNode(fajlovi[i]);
		if(fajlovi[i].isDirectory())
		    fsnode.add(new DefaultMutableTreeNode());
		node.add(fsnode);
		load(fsnode,depth+1);
	    }
	}
    }
    
    public void loadOne(FSTreeNode node){
	
	//ucitavamo pojedinacni cvor, dakle listamo samo 
	//direktorijum na kliknutoj lokaciji
	File f = new File(node.path);
	File[] files = f.listFiles();
	node.removeAllChildren();
	if (files != null) {
	    Object[] novi=new Object[files.length]; 
			int[] indices=new int[files.length];
	    for (int i = 0; i < files.length; i++) {
		FSTreeNode fsnode = new FSTreeNode(files[i]);
		indices[i]=i;
		novi[i]=fsnode;
		if(files[i].isDirectory())
		    fsnode.add(new FSTreeNode(f));
		node.add(fsnode);
	    }
	    //obavestavamo graficku komponentu o dodatim elementima u modelu
	    fireTreeNodesInserted(this, node.getPath(), indices, novi);
	}
    }

}

class FSTreeNode extends DefaultMutableTreeNode {

    String name;

    String path;

    boolean isDirectory;

    Date lastChange;

    public FSTreeNode(File f) {
	super();
	name = f.getName();
	path = f.getPath();
	isDirectory = f.isDirectory();
	lastChange = new Date(f.lastModified());
    }

    @Override
    public String toString() {
	return name;
    }
    
    
}
